# Changelog

## v1.2.0 - 2023-06-12

Remove explicit dependence on glue-core, and improve CI and tests.

**Full Changelog**: https://github.com/gluesolutions/glue-small-multiples/compare/v1.1.2...v1.2.0

## v1.1.1

Fix call to the removed glue.utils broadcast_to function

## v1.1

First pypi release

## v1.0.1

### Bug Fixes

```- Subsets respect zorder
- Plot styles survive save/restore
```
## v1.0

Initial Release
